<?php
/*
Plugin Name: Advanced Tagline
Plugin URI: http://kmorey.net/downloads/advanced-tagline-wordpress-plugin
Description: This plugin gives the option to have multiple taglines for your blog and display them at random or sequentially with each page view
Author: Kevin Morey
Version: 1.3
Author URI: http://kmorey.net
*/

define(ADVTAG_VERSION, "1.3");
define(ADVTAG_TAGPAIRS, "advtag_tags");
define(ADVTAG_TYPE, "advtag_type");

global $advtag_tags;
global $advtag_type;
$advtag_tags = get_option(ADVTAG_TAGPAIRS);
$advtag_type = get_option(ADVTAG_TYPE);

if (!isset($advtag_tags)) {
  $advtag_tags = array();
}

function advtag_options_page()
{
  global $advtag_tags;
  global $advtag_type;

  $message="";
  $error = FALSE;
  
  //normal save
  if (!empty($_POST['save'])) {
    $advtag_tags = array();

    $tags = $_POST['tag'];
    $links = $_POST['link'];

    for($i=0; $i<count($tags); $i++) {
      if ($tags[$i] != "" && !$_POST["remove-$i"]) {
        $advtag_tags[] = array($tags[$i], $links[$i]);
      }
    }

    $advtag_type = $_POST['rotate_type'];

    update_option(ADVTAG_TAGPAIRS, $advtag_tags);
    update_option(ADVTAG_TYPE, $advtag_type);

    $message.=__('Save successful.', 'advtag');
  }
  //batch import
  else if (!empty($_POST['import'])) {
    $fileName = $_FILES['importfile']['tmp_name'];
    
    if (empty($fileName)) {
      
      $message = "Import failed: no file specified.";
      $error = TRUE;
      
    } else {
    
      $tagLines = advtag_parse_csv($fileName);
  
      if (!is_array($tagLines)) {
        //error handling
        $message.=__('Parse import file failed. Ensure file is in correct format.', 'advtag');
        $message.="<br />$tagLines";
        $error = TRUE;
      } else {
        if ($_POST['import_type'] == 'replace') { $advtag_tags = array(); }
        
        foreach ($tagLines as $tagLine) {
          $advtag_tags[] = $tagLine;
        }
        
        update_option(ADVTAG_TAGPAIRS, $advtag_tags);
        $message.=__('Import successful.', 'advtag');
      }
    }
  }

  include("settings.php");

  $script = "<script type='text/javascript'>\n";
  foreach($advtag_tags as $tagpair) {
    $text = $tagpair[0];
    $link = $tagpair[1];
    $script .= "  advtag_newTagline(\"$text\",\"$link\");\n";
  }
  $script .= "</script>\n";
  print($script);
}

function advtag_parse_csv($fileName) {
  $results = array();
  $handle = fopen($fileName, "r");
  
  while (($data = fgetcsv($handle, 4096)) !== FALSE) {
    //skip blank lines, which return an array comprising a single null field
    if (count($data) > 0 && $data[0] == null) { continue; }
    
    if (count($data) == 1) {
      $results[] = array($data[0], '');
    }
    else if (count($data) != 2) {
      $results[] = $data;
    } else {
      //error: invalid format (two cols per row only) 
      return "Invalid format (1 or 2 columns expected, found ".count($data).")."; 
    }
    
  }
  fclose($handle);
  
  return $results;
}

function prepare_for_input($value) {
  return str_replace('"', '&quot;', $value);
}

function advtag_update_option($key, $value) {
  if( get_magic_quotes_gpc() ) {
    $value = stripslashes($value);
  }
  update_option($key, $value);
}

function advtag_admin_menu() {
  if (function_exists('add_options_page'))
  {
    add_options_page('Advanced Tagline', 'Advanced Tagline', 8, basename(__FILE__), 'advtag_options_page');
  }
}

function advtag_next_tagline() {
  global $advtag_type;
  global $advtag_tags;

  //i haven't figured out why yet (not much looking) but the header file is parsed when the
  //.css is imported so skip that
  if ($advtag_type == "sequential" && !preg_match("/\.css$/", $_SERVER['HTTP_REFERER'])) {
    $idx = $_COOKIE["advtag_idx"] + 1;
    if ($idx >= count($advtag_tags)) { $idx = 0; }
    setcookie("advtag_idx", $idx, 0, "/");
  }
}

function advtag_get_tagline() {
  global $advtag_tags;
  global $advtag_type;
  $idx = 0;

  if ($advtag_type == "sequential") {
    $idx = $_COOKIE["advtag_idx"];
  } else {
    $idx = mt_rand(0, count($advtag_tags) - 1);
  }
  
  if (empty($idx)) { $idx = 0; }

  $link = stripslashes($advtag_tags[$idx][1]);
  $text = stripslashes($advtag_tags[$idx][0]);
  
  if (!empty($link)) {
    echo '<a href="'.$link.'">'.$text.'</a>';
  } else {
    echo $text;
  }
}

function advtag_script() {
  $path = get_option('siteurl')."/wp-content/plugins/advanced-tagline/";
  $html.= "<link rel=\"stylesheet\" href=\"".$path."advtag.css\" type=\"text/css\" media=\"screen\" />\n";
  $html.= "<script type=\"text/javascript\" src=\"".$path."mootools-1.2-core.js\"></script>\n";
  $html.= "<script type=\"text/javascript\" src=\"".$path."mootools-1.2-more.js\"></script>\n";
  $html.= "<script type=\"text/javascript\" src=\"".$path."advtag.js\"></script>\n";
  
  $html.="
  <script type=\"text/javascript\">
    window.addEvent('domready', function() {      
      new Accordion($('accordion'), 'h3.toggler', 'div.element', {
        opacity: false,
        alwaysHide: true,
      });
    });
  </script>
  ";

  print($html);
}

add_action('admin_menu', 'advtag_admin_menu');
add_action('admin_head', 'advtag_script');
?>
